
/* Generated data (by glib-mkenums) */

#ifndef __TB_ENUM_TYPES_H__
#define __TB_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "tb/tb-box.h" */
GType tb_box_pack_flags_get_type (void) G_GNUC_CONST;
#define TB_TYPE_BOX_PACK_FLAGS (tb_box_pack_flags_get_type())

GType tb_box_alignment_get_type (void) G_GNUC_CONST;
#define TB_TYPE_BOX_ALIGNMENT (tb_box_alignment_get_type())

GType tb_box_orientation_get_type (void) G_GNUC_CONST;
#define TB_TYPE_BOX_ORIENTATION (tb_box_orientation_get_type())

/* enumerations from "tb/tb-sound-player.h" */
GType tb_sound_player_state_get_type (void) G_GNUC_CONST;
#define TB_TYPE_SOUND_PLAYER_STATE (tb_sound_player_state_get_type())

/* enumerations from "tb/tb-sound-recorder.h" */
GType tb_sound_recorder_state_get_type (void) G_GNUC_CONST;
#define TB_TYPE_SOUND_RECORDER_STATE (tb_sound_recorder_state_get_type())

G_END_DECLS

#endif /* !__TB_ENUM_TYPES_H__ */

/* Generated data ends here */

